@@ -1,5 +1,3 @@
-import logging
-logging.basicConfig()
 from pvlib.version import __version__
 from pvlib import tools
 from pvlib import atmosphere
