@@ -6,8 +6,6 @@ irradiance, and total irradiance under various conditions.
 
 from __future__ import division
 
-import logging
-
 import datetime
 from collections import OrderedDict
 from functools import partial
@@ -19,7 +17,6 @@ from pvlib import tools
 from pvlib import solarposition
 from pvlib import atmosphere
 
-pvl_logger = logging.getLogger('pvlib')
 
 SURFACE_ALBEDOS = {'urban': 0.18,
                    'grass': 0.20,
@@ -294,13 +291,20 @@ def total_irrad(surface_tilt, surface_azimuth,
                 model='isotropic',
                 model_perez='allsitescomposite1990', **kwargs):
     r"""
-    Determine diffuse irradiance from the sky on a tilted surface.
+    Determine total in-plane irradiance and its beam, sky diffuse and ground
+    reflected components, using the specified sky diffuse irradiance model.
 
     .. math::
 
-       I_{tot} = I_{beam} + I_{sky} + I_{ground}
+       I_{tot} = I_{beam} + I_{sky diffuse} + I_{ground}
 
-    See the transposition function documentation for details.
+    Sky diffuse models include:
+        * isotropic (default)
+        * klucher
+        * haydavies
+        * reindl
+        * king
+        * perez
 
     Parameters
     ----------
@@ -333,13 +337,11 @@ def total_irrad(surface_tilt, surface_azimuth,
 
     Returns
     -------
-    irradiance : OrderedDict or DataFrame
-        Contains keys/columns ``'poa_global', 'poa_direct', 'poa_diffuse', 
+    total_irrad : OrderedDict or DataFrame
+        Contains keys/columns ``'poa_global', 'poa_direct', 'poa_diffuse',
         'poa_sky_diffuse', 'poa_ground_diffuse'``.
     """
 
-    pvl_logger.debug('planeofarray.total_irrad()')
-
     solar_zenith = apparent_zenith
     solar_azimuth = azimuth
 
@@ -491,12 +493,8 @@ def grounddiffuse(surface_tilt, ghi, albedo=.25, surface_type=None):
     http://en.wikipedia.org/wiki/Albedo
     '''
 
-    pvl_logger.debug('diffuse_ground.get_diffuse_ground()')
-
     if surface_type is not None:
         albedo = SURFACE_ALBEDOS[surface_type]
-        pvl_logger.info('surface_type=%s mapped to albedo=%s',
-                        surface_type, albedo)
 
     diffuse_irrad = ghi * albedo * (1 - np.cos(np.radians(surface_tilt))) * 0.5
 
@@ -548,8 +546,6 @@ def isotropic(surface_tilt, dhi):
     heat collector. Trans. ASME 64, 91.
     '''
 
-    pvl_logger.debug('diffuse_sky.isotropic()')
-
     sky_diffuse = dhi * (1 + tools.cosd(surface_tilt)) * 0.5
 
     return sky_diffuse
@@ -621,8 +617,6 @@ def klucher(surface_tilt, surface_azimuth, dhi, ghi, solar_zenith,
     tilted surfaces. Solar Energy 23 (2), 111-114.
     '''
 
-    pvl_logger.debug('diffuse_sky.klucher()')
-
     # zenith angle with respect to panel normal.
     cos_tt = aoi_projection(surface_tilt, surface_azimuth,
                             solar_zenith, solar_azimuth)
@@ -712,8 +706,6 @@ def haydavies(surface_tilt, surface_azimuth, dhi, dni, dni_extra,
     Ministry of Supply and Services, Canada.
     '''
 
-    pvl_logger.debug('diffuse_sky.haydavies()')
-
     # if necessary, calculate ratio of titled and horizontal beam irradiance
     if projection_ratio is None:
         cos_tt = aoi_projection(surface_tilt, surface_azimuth,
@@ -812,8 +804,6 @@ def reindl(surface_tilt, surface_azimuth, dhi, dni, ghi, dni_extra,
     hourly tilted surface radiation models. Solar Energy 45(1), 9-17.
     '''
 
-    pvl_logger.debug('diffuse_sky.reindl()')
-
     cos_tt = aoi_projection(surface_tilt, surface_azimuth,
                             solar_zenith, solar_azimuth)
 
@@ -874,8 +864,6 @@ def king(surface_tilt, dhi, ghi, solar_zenith):
         The diffuse component of the solar radiation.
     '''
 
-    pvl_logger.debug('diffuse_sky.king()')
-
     sky_diffuse = (dhi * ((1 + tools.cosd(surface_tilt))) / 2 + ghi *
                    ((0.012 * solar_zenith - 0.04)) *
                    ((1 - tools.cosd(surface_tilt))) / 2)
@@ -988,7 +976,8 @@ def perez(surface_tilt, surface_azimuth, dhi, dni, dni_extra,
     delta = dhi * airmass / dni_extra
 
     # epsilon is the sky's "clearness"
-    eps = ((dhi + dni) / dhi + kappa * (z ** 3)) / (1 + kappa * (z ** 3))
+    with np.errstate(invalid='ignore'):
+        eps = ((dhi + dni) / dhi + kappa * (z ** 3)) / (1 + kappa * (z ** 3))
 
     # numpy indexing below will not work with a Series
     if isinstance(eps, pd.Series):
@@ -998,15 +987,8 @@ def perez(surface_tilt, surface_azimuth, dhi, dni, dni_extra,
     # rules. 1 = overcast ... 8 = clear (these names really only make
     # sense for small zenith angles, but...) these values will
     # eventually be used as indicies for coeffecient look ups
-    ebin = np.zeros_like(eps, dtype=np.int8)
-    ebin[eps < 1.065] = 1
-    ebin[(eps >= 1.065) & (eps < 1.23)] = 2
-    ebin[(eps >= 1.23) & (eps < 1.5)] = 3
-    ebin[(eps >= 1.5) & (eps < 1.95)] = 4
-    ebin[(eps >= 1.95) & (eps < 2.8)] = 5
-    ebin[(eps >= 2.8) & (eps < 4.5)] = 6
-    ebin[(eps >= 4.5) & (eps < 6.2)] = 7
-    ebin[eps >= 6.2] = 8
+    ebin = np.digitize(eps, (0., 1.065, 1.23, 1.5, 1.95, 2.8, 4.5, 6.2))
+    ebin[np.isnan(eps)] = 0
 
     # correct for 0 indexing in coeffecient lookup
     # later, ebin = -1 will yield nan coefficients
@@ -1326,8 +1308,8 @@ def dirindex(ghi, ghi_clearsky, dni_clearsky, zenith, times, pressure=101325.,
     Determine DNI from GHI using the DIRINDEX model, which is a modification of
     the DIRINT model with information from a clear sky model.
 
-    DIRINDEX [1] improves upon the DIRINT model by taking into account turbidity
-    when used with the Ineichen clear sky model results.
+    DIRINDEX [1] improves upon the DIRINT model by taking into account
+    turbidity when used with the Ineichen clear sky model results.
 
     Parameters
     ----------
@@ -1389,7 +1371,8 @@ def dirindex(ghi, ghi_clearsky, dni_clearsky, zenith, times, pressure=101325.,
                         use_delta_kt_prime=use_delta_kt_prime,
                         temp_dew=temp_dew)
 
-    dni_dirint_clearsky = dirint(ghi_clearsky, zenith, times, pressure=pressure,
+    dni_dirint_clearsky = dirint(ghi_clearsky, zenith, times,
+                                 pressure=pressure,
                                  use_delta_kt_prime=use_delta_kt_prime,
                                  temp_dew=temp_dew)
 
@@ -1489,8 +1472,7 @@ def erbs(ghi, zenith, doy):
     return data
 
 
-def liujordan(zenith, transmittance, airmass, pressure=101325.,
-              dni_extra=1367.0):
+def liujordan(zenith, transmittance, airmass, dni_extra=1367.0):
     '''
     Determine DNI, DHI, GHI from extraterrestrial flux, transmittance,
     and optical air mass number.
@@ -1531,10 +1513,10 @@ def liujordan(zenith, transmittance, airmass, pressure=101325.,
     radiation".  Solar Energy 4:1-19
     '''
 
-    tao = transmittance
+    tau = transmittance
 
-    dni = dni_extra*tao**airmass
-    dhi = 0.3 * (1.0 - tao**airmass) * dni_extra * np.cos(np.radians(zenith))
+    dni = dni_extra*tau**airmass
+    dhi = 0.3 * (1.0 - tau**airmass) * dni_extra * np.cos(np.radians(zenith))
     ghi = dhi + dni * np.cos(np.radians(zenith))
 
     irrads = OrderedDict()
