@@ -732,9 +732,10 @@ def ashraeiam(aoi, b=0.05):
     physicaliam
     '''
 
-    iam = 1 - b*((1/np.cos(np.radians(aoi)) - 1))
-
-    iam = np.where(np.abs(aoi) >= 90, 0, iam)
+    iam = 1 - b * ((1 / np.cos(np.radians(aoi)) - 1))
+    aoi_gte_90 = np.full_like(aoi, False, dtype='bool')
+    np.greater_equal(np.abs(aoi), 90, where=~np.isnan(aoi), out=aoi_gte_90)
+    iam = np.where(aoi_gte_90, 0, iam)
     iam = np.maximum(0, iam)
 
     if isinstance(iam, pd.Series):
@@ -746,18 +747,17 @@ def ashraeiam(aoi, b=0.05):
 def physicaliam(aoi, n=1.526, K=4., L=0.002):
     '''
     Determine the incidence angle modifier using refractive index,
-    glazing thickness, and extinction coefficient
+    extinction coefficient, and glazing thickness.
 
     physicaliam calculates the incidence angle modifier as described in
     De Soto et al. "Improvement and validation of a model for
     photovoltaic array performance", section 3. The calculation is based
-    upon a physical model of absorbtion and transmission through a
-    cover. Required information includes, incident angle, cover
-    extinction coefficient, cover thickness
+    on a physical model of absorbtion and transmission through a
+    cover.
 
     Note: The authors of this function believe that eqn. 14 in [1] is
     incorrect. This function uses the following equation in its place:
-    theta_r = arcsin(1/n * sin(theta))
+    theta_r = arcsin(1/n * sin(aoi))
 
     Parameters
     ----------
@@ -788,14 +788,8 @@ def physicaliam(aoi, n=1.526, K=4., L=0.002):
 
     Returns
     -------
-    IAM : numeric
-        The incident angle modifier as specified in eqns. 14-16 of [1].
-        IAM is a column vector with the same number of elements as the
-        largest input vector.
-
-        Theta must be a numeric scalar or vector. For any values of
-        theta where abs(aoi)>90, IAM is set to 0. For any values of aoi
-        where -90 < aoi < 0, theta is set to abs(aoi) and evaluated.
+    iam : numeric
+        The incident angle modifier
 
     References
     ----------
@@ -816,6 +810,11 @@ def physicaliam(aoi, n=1.526, K=4., L=0.002):
     '''
     zeroang = 1e-06
 
+    # hold a new reference to the input aoi object since we're going to
+    # overwrite the aoi reference below, but we'll need it for the
+    # series check at the end of the function
+    aoi_input = aoi
+
     aoi = np.where(aoi == 0, zeroang, aoi)
 
     # angle of reflection
@@ -838,19 +837,21 @@ def physicaliam(aoi, n=1.526, K=4., L=0.002):
     # after deducting the reflected portion of each
     iam = ((1 - (rho_para + rho_perp) / 2) / (1 - rho_zero) * tau / tau_zero)
 
-    # angles near zero produce nan, but iam is defined as one
-    small_angle = 1e-06
-    iam = np.where(np.abs(aoi) < small_angle, 1.0, iam)
+    with np.errstate(invalid='ignore'):
+        # angles near zero produce nan, but iam is defined as one
+        small_angle = 1e-06
+        iam = np.where(np.abs(aoi) < small_angle, 1.0, iam)
 
-    # angles at 90 degrees can produce tiny negative values, which should be zero
-    # this is a result of calculation precision rather than the physical model
-    iam = np.where(iam < 0, 0, iam)
+        # angles at 90 degrees can produce tiny negative values,
+        # which should be zero. this is a result of calculation precision
+        # rather than the physical model
+        iam = np.where(iam < 0, 0, iam)
 
-    # for light coming from behind the plane, none can enter the module
-    iam = np.where(aoi > 90, 0, iam)
+        # for light coming from behind the plane, none can enter the module
+        iam = np.where(aoi > 90, 0, iam)
 
-    if isinstance(aoi, pd.Series):
-        iam = pd.Series(iam, index=aoi.index)
+    if isinstance(aoi_input, pd.Series):
+        iam = pd.Series(iam, index=aoi_input.index)
 
     return iam
 
@@ -1143,7 +1144,7 @@ def retrieve_sam(name=None, path=None):
             os.path.dirname(os.path.abspath(__file__)), 'data')
         if name == 'cecmod':
             csvdata = os.path.join(
-                data_path, 'sam-library-cec-modules-2015-6-30.csv')
+                data_path, 'sam-library-cec-modules-2017-6-5.csv')
         elif name == 'sandiamod':
             csvdata = os.path.join(
                 data_path, 'sam-library-sandia-modules-2015-6-30.csv')
@@ -1153,7 +1154,7 @@ def retrieve_sam(name=None, path=None):
             # Allowing either, to provide for old code,
             # while aligning with current expectations
             csvdata = os.path.join(
-                data_path, 'sam-library-cec-inverters-2015-6-30.csv')
+                data_path, 'sam-library-cec-inverters-2018-3-18.csv')
         else:
             raise ValueError('invalid name {}'.format(name))
     elif path is not None:
@@ -1298,12 +1299,27 @@ def sapm(effective_irradiance, temp_cell, module):
     q = 1.60218e-19  # Elementary charge in units of coulombs
     kb = 1.38066e-23  # Boltzmann's constant in units of J/K
 
-    Ee = effective_irradiance
+    # avoid problem with integer input
+    Ee = np.array(effective_irradiance, dtype='float64')
+
+    # set up masking for 0, positive, and nan inputs
+    Ee_gt_0 = np.full_like(Ee, False, dtype='bool')
+    Ee_eq_0 = np.full_like(Ee, False, dtype='bool')
+    notnan = ~np.isnan(Ee)
+    np.greater(Ee, 0, where=notnan, out=Ee_gt_0)
+    np.equal(Ee, 0, where=notnan, out=Ee_eq_0)
 
     Bvmpo = module['Bvmpo'] + module['Mbvmp']*(1 - Ee)
     Bvoco = module['Bvoco'] + module['Mbvoc']*(1 - Ee)
     delta = module['N'] * kb * (temp_cell + 273.15) / q
 
+    # avoid repeated computation
+    logEe = np.full_like(Ee, np.nan)
+    np.log(Ee, where=Ee_gt_0, out=logEe)
+    logEe = np.where(Ee_eq_0, -np.inf, logEe)
+    # avoid repeated __getitem__
+    cells_in_series = module['Cells_in_Series']
+
     out = OrderedDict()
 
     out['i_sc'] = (
@@ -1314,13 +1330,13 @@ def sapm(effective_irradiance, temp_cell, module):
         (1 + module['Aimp']*(temp_cell - T0)))
 
     out['v_oc'] = np.maximum(0, (
-        module['Voco'] + module['Cells_in_Series']*delta*np.log(Ee) +
+        module['Voco'] + cells_in_series * delta * logEe +
         Bvoco*(temp_cell - T0)))
 
     out['v_mp'] = np.maximum(0, (
         module['Vmpo'] +
-        module['C2']*module['Cells_in_Series']*delta*np.log(Ee) +
-        module['C3']*module['Cells_in_Series']*((delta*np.log(Ee)) ** 2) +
+        module['C2'] * cells_in_series * delta * logEe +
+        module['C3'] * cells_in_series * ((delta * logEe) ** 2) +
         Bvmpo*(temp_cell - T0)))
 
     out['p_mp'] = out['i_mp'] * out['v_mp']
@@ -1520,7 +1536,10 @@ def sapm_aoi_loss(aoi, module, upper=None):
 
     aoi_loss = np.polyval(aoi_coeff, aoi)
     aoi_loss = np.clip(aoi_loss, 0, upper)
-    aoi_loss = np.where(aoi < 0, 0, aoi_loss)
+    # nan tolerant masking
+    aoi_lt_0 = np.full_like(aoi, False, dtype='bool')
+    np.less(aoi, 0, where=~np.isnan(aoi), out=aoi_lt_0)
+    aoi_loss = np.where(aoi_lt_0, 0, aoi_loss)
 
     if isinstance(aoi, pd.Series):
         aoi_loss = pd.Series(aoi_loss, aoi.index)
@@ -1914,9 +1933,11 @@ def v_from_i(resistance_shunt, resistance_series, nNsVth, current,
     # Only compute using LambertW if there are cases with Gsh>0
     if np.any(idx_p):
         # LambertW argument, cannot be float128, may overflow to np.inf
-        argW = I0[idx_p] / (Gsh[idx_p]*a[idx_p]) * \
-            np.exp((-I[idx_p] + IL[idx_p] + I0[idx_p]) /
-                   (Gsh[idx_p]*a[idx_p]))
+        # overflow is explicitly handled below, so ignore warnings here
+        with np.errstate(over='ignore'):
+            argW = (I0[idx_p] / (Gsh[idx_p]*a[idx_p]) *
+                    np.exp((-I[idx_p] + IL[idx_p] + I0[idx_p]) /
+                           (Gsh[idx_p]*a[idx_p])))
 
         # lambertw typically returns complex value with zero imaginary part
         # may overflow to np.inf
@@ -2276,22 +2297,39 @@ def adrinverter(v_dc, p_dc, inverter, vtol=0.10):
     mppt_hi = inverter['MPPTHi']
     mppt_low = inverter['MPPTLow']
 
-    v_lim_upper = np.nanmax([v_max, vdc_max, mppt_hi])*(1+vtol)
-    v_lim_lower = np.nanmax([v_min, mppt_low])*(1-vtol)
+    v_lim_upper = np.nanmax([v_max, vdc_max, mppt_hi]) * (1 + vtol)
+    v_lim_lower = np.nanmax([v_min, mppt_low]) * (1 - vtol)
 
-    pdc = p_dc/p_nom
-    vdc = v_dc/v_nom
-    poly = np.array([pdc**0, pdc, pdc**2, vdc-1, pdc*(vdc-1),
-                     pdc**2*(vdc-1), 1/vdc-1, pdc*(1./vdc-1),
-                     pdc**2*(1./vdc-1)])
+    pdc = p_dc / p_nom
+    vdc = v_dc / v_nom
+    # zero voltage will lead to division by zero, but since power is
+    # set to night time value later, these errors can be safely ignored
+    with np.errstate(invalid='ignore', divide='ignore'):
+        poly = np.array([pdc**0,  # replace with np.ones_like?
+                         pdc,
+                         pdc**2,
+                         vdc - 1,
+                         pdc * (vdc - 1),
+                         pdc**2 * (vdc - 1),
+                         1. / vdc - 1,  # divide by 0
+                         pdc * (1. / vdc - 1),  # invalid 0./0. --> nan
+                         pdc**2 * (1. / vdc - 1)])  # divide by 0
     p_loss = np.dot(np.array(ce_list), poly)
     ac_power = p_nom * (pdc-p_loss)
-    p_nt = -1*np.absolute(p_nt)
+    p_nt = -1 * np.absolute(p_nt)
 
-    ac_power = np.where((v_lim_upper < v_dc) | (v_dc < v_lim_lower),
-                        np.nan, ac_power)
-    ac_power = np.where((ac_power < p_nt) | (vdc == 0), p_nt, ac_power)
-    ac_power = np.where(ac_power > pac_max, pac_max, ac_power)
+    # set output to nan where input is outside of limits
+    # errstate silences case where input is nan
+    with np.errstate(invalid='ignore'):
+        invalid = (v_lim_upper < v_dc) | (v_dc < v_lim_lower)
+    ac_power = np.where(invalid, np.nan, ac_power)
+
+    # set night values
+    ac_power = np.where(vdc == 0, p_nt, ac_power)
+    ac_power = np.maximum(ac_power, p_nt)
+
+    # set max ac output
+    ac_power = np.minimum(ac_power, pac_max)
 
     if isinstance(p_dc, pd.Series):
         ac_power = pd.Series(ac_power, index=pdc.index)
