@@ -8,9 +8,6 @@ from pvlib.pvsystem import PVSystem
 from pvlib.location import Location
 from pvlib import irradiance, atmosphere
 
-import logging
-pvl_logger = logging.getLogger('pvlib')
-
 
 class SingleAxisTracker(PVSystem):
     """
@@ -307,15 +304,6 @@ def singleaxis(apparent_zenith, apparent_azimuth,
     Photovoltaics: Research and Applications, v. 19, pp. 747-753.
     """
 
-    pvl_logger.debug('tracking.singleaxis')
-
-    pvl_logger.debug('axis_tilt=%s, axis_azimuth=%s, max_angle=%s, '
-                     'backtrack=%s, gcr=%.3f',
-                     axis_tilt, axis_azimuth, max_angle, backtrack, gcr)
-
-    pvl_logger.debug('\napparent_zenith=\n%s\napparent_azimuth=\n%s',
-                     apparent_zenith.head(), apparent_azimuth.head())
-
     # MATLAB to Python conversion by
     # Will Holmgren (@wholmgren), U. Arizona. March, 2015.
 
@@ -354,7 +342,6 @@ def singleaxis(apparent_zenith, apparent_azimuth,
     # wholmgren: strange to see axis_azimuth calculated differently from az,
     # (not that it matters, or at least it shouldn't...).
     axis_azimuth_south = axis_azimuth - 180
-    pvl_logger.debug('axis_azimuth_south=%s', axis_azimuth_south)
 
     # translate input array tilt angle axis_tilt to [1] coordinate system.
 
@@ -418,7 +405,6 @@ def singleaxis(apparent_zenith, apparent_azimuth,
     # Account for backtracking; modified from [1] to account for rotation
     # angle convention being used here.
     if backtrack:
-        pvl_logger.debug('applying backtracking')
         axes_distance = 1/gcr
         temp = np.minimum(axes_distance*cosd(wid), 1)
 
@@ -431,7 +417,6 @@ def singleaxis(apparent_zenith, apparent_azimuth,
         widc[~v] = wid[~v] - wc[~v]  # Eq 4 applied when wid in QI
         widc[v] = wid[v] + wc[v]     # Eq 4 applied when wid in QIV
     else:
-        pvl_logger.debug('no backtracking')
         widc = wid
 
     tracker_theta = widc.copy()
@@ -469,34 +454,27 @@ def singleaxis(apparent_zenith, apparent_azimuth,
     rot_x = np.array([[1, 0, 0],
                       [0, cosd(-axis_tilt), -sind(-axis_tilt)],
                       [0, sind(-axis_tilt), cosd(-axis_tilt)]])
-    pvl_logger.debug('rot_x=\n%s', rot_x)
 
     # panel_norm_earth contains the normal vector
     # expressed in earth-surface coordinates
     # (z normal to surface, y aligned with tracker axis parallel to earth)
     panel_norm_earth = np.dot(rot_x, panel_norm).T
-    pvl_logger.debug('panel_norm_earth=%s', panel_norm_earth)
 
     # projection to plane tangent to earth surface,
     # in earth surface coordinates
     projected_normal = np.array([panel_norm_earth[:, 0],
                                  panel_norm_earth[:, 1],
                                  panel_norm_earth[:, 2]*0]).T
-    pvl_logger.debug('projected_normal=%s', projected_normal)
 
     # calculate vector magnitudes
     panel_norm_earth_mag = np.sqrt(np.nansum(panel_norm_earth**2, axis=1))
     projected_normal_mag = np.sqrt(np.nansum(projected_normal**2, axis=1))
-    pvl_logger.debug('panel_norm_earth_mag=%s, projected_normal_mag=%s',
-                     panel_norm_earth_mag, projected_normal_mag)
 
     # renormalize the projected vector
     # avoid creating nan values.
     non_zeros = projected_normal_mag != 0
     projected_normal[non_zeros] = (projected_normal[non_zeros].T /
                                    projected_normal_mag[non_zeros]).T
-    pvl_logger.debug('renormalized projected_normal=%s',
-                     projected_normal)
 
     # calculation of surface_azimuth
     # 1. Find the angle.
